Learn R Programming

RTOMO (version 1.1-3)

RTOMO-package: Plot and Interact with Tomographic Images

Description

Created mainly for use with seismic tomography, this program plots tomographic images, and allows one to interact and query three-dimensional tomographic models. Vertical cross-sectional cuts can be extracted by mouse click. Geographic information can be added easily.

Arguments

Details

Package:
RTOMO
Type:
Package
Version:
1.0-9
Date:
2012-07-30-15
License:
GPL
Visualization for seismic tomography, includes:
TOMO3D.drive
Interactive tomography exploration

SHOWTOMO
show tomographic model in multi-panel display

FANCY.TOMO
Tomographic plot of one layer

pltomo
plot one horizontal slice of tomogram

XSEC.drive
Interactive plot of vertical cross section

PLOT.TOMOXSEC
plot Cross section of tomographic model

TOMOXSEC
Vertical Cross section through model

Model I/O:

GXMA3D
Get 3D perturbation model in geotouch format

GXMA3DV
Get 3D velocity model in geotouch format

makeMOD
Make 3D synthetic model

Utilities:

tomo.colors
color palette for tomography

TOMOinfo
Information about the tomographic layers

MOD2VEC
Convert 3D model to single long vector

VEC2MOD
Convert single long vector to 3D model

get2Drayblox
get 2D ray blocks

get3Drayblox
get 3D ray blocks

References

J. M. Lees. Geotouch: Software for three and four dimensional GIS in the earth sciences. Computers and Geosciences , 26(7):751--761, 2000.

See Also

RSEIS

Examples

Run this code
data(HELMOD)
data(HELMAP)

TOMO3D.drive(HELMOD, MAP=HELMAP)


Run the code above in your browser using DataLab