Learn R Programming

RTOMO (version 1.1-3)

pltomo: plot a layer in 3D tomogram

Description

Simple plot of a layer in 3D tomogram

Usage

pltomo(x,y,MOD,i, colmap=rainbow(100), zlim=NULL, bkgr="DarkSlateGray4", ...)

Arguments

x
x nodes
y
y nodes
MOD
Model Structure
i
layer to plot
colmap
color palette
zlim
vector (v1, v2) limit of z values
bkgr
background color for NA values
...
graphical parameters from par()

Value

Graphical Side effects

Details

Does not set the projection, does not add any markup - all this does is start the plotting set up and puts the image on the plot.

See Also

FANCY.TOMO, SHOWTOMO, GXMA3DV

Examples

Run this code

data(HELMOD)
 pltomo(HELMOD$x,HELMOD$y,HELMOD$MOD,5, col=tomo.colors(100), zlim=NULL,  bkgr="white" )
      


Run the code above in your browser using DataLab